"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _superagent = _interopRequireDefault(require("superagent"));

var _reduxQueryImmutable = require("redux-query-immutable");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var createRequest = function createRequest(url, method) {
  switch (method) {
    case _reduxQueryImmutable.httpMethods.HEAD:
      return _superagent["default"].head(url);

    case _reduxQueryImmutable.httpMethods.GET:
      return _superagent["default"].get(url);

    case _reduxQueryImmutable.httpMethods.POST:
      return _superagent["default"].post(url);

    case _reduxQueryImmutable.httpMethods.PUT:
      return _superagent["default"].put(url);

    case _reduxQueryImmutable.httpMethods.PATCH:
      return _superagent["default"].patch(url);

    case _reduxQueryImmutable.httpMethods.DELETE:
      return _superagent["default"]["delete"](url);

    default:
      throw new Error("Unsupported HTTP method: ".concat(method));
  }
};

var superagentNetworkInterface = function superagentNetworkInterface(url, method) {
  var _ref = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {},
      body = _ref.body,
      headers = _ref.headers,
      credentials = _ref.credentials,
      multipart = _ref.multipart;

  var request = createRequest(url, method);

  if (headers) {
    request.set(headers);
  }

  if (body && !multipart) {
    request.send(body);
  }

  if (credentials === 'include') {
    request.withCredentials();
  }

  if (body && multipart) {
    if (_reduxQueryImmutable.httpMethods.POST !== method) throw new Error('Files can only be uploaded with POST requests.');
    var fields = body.fields,
        files = body.files;
    Array.isArray(fields) && fields.forEach(function (field) {
      return request.field(field.key, field.value);
    });
    Array.isArray(files) && files.forEach(function (file) {
      return request.attach(file.key, file.value);
    });
  }

  var execute = function execute(cb) {
    request.end(function (err, response) {
      var resStatus = response && response.status || 0;
      var resBody = response && response.body || undefined;
      var resText = response && response.text || undefined;
      var resHeaders = response && response.header || undefined;
      cb(err, resStatus, resBody, resText, resHeaders);
    });
  };

  var abort = function abort() {
    return request.abort();
  };

  return {
    abort: abort,
    execute: execute
  };
};

var _default = superagentNetworkInterface;
exports["default"] = _default;